//Source file: CallEventType.java
//Date: December 2004
//Multi Party Call Control Data Types for 3GPP TS 29.198-04-3 V5.9.0

package org.csapi.jr.se.cc;

/**
 * Defines a specific call event report type.
EVENT HANDLING RULES:
The following general event handling rules apply to dynamically armed events:
When requesting events for one leg:
When the monitor mode is set to P_CALL_MONITOR_MODE_DO_NOT_MONITOR all events armed for that event type are disarmed. The additionalEventCriteria are not taken into account.
When requesting two events for the same event type with different criteria and/or different monitor mode the last used criteria and monitor mode apply.
Events that are not applicable to a leg are refused with exception P_INVALID_EVENT_TYPE. The same exception is used when criteria are used that are not applicable to the leg,
For example requesting P_CALL_EVENT_TERMINATING_SERVICE_CODE on an originating leg is refused with exception P_INVALID_CRITERIA.
When P_CALL_EVENT_ORIGINATING_RELEASE is requested with P_BUSY in the criteria the request is refused with the same exception.
When receiving events:
If an armed event is met, then it is disarmed, unless explicit stated that it will not to be disarmed.
If an event is met that causes the release of the related leg, then all events related to that leg are disarmed.
When an event is met on a call leg irrespective of the event monitor mode, then only events belonging to that call leg may become disarmed (see table below).
If a call is released, then all events related to that call are disarmed.
NOTE 1:	Event disarmed means monitor mode is set to DO_NOT_MONITOR. and 
event armed means monitor mode is set to INTERRUPT or NOTIFY.
 *
 */
public final class CallEventType implements java.io.Serializable {

    private int _value;
    private static int _size = 15;
    private static CallEventType[] _array = new CallEventType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private CallEventType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined
     */
    public static final int _CALL_EVENT_UNDEFINED =  0;

    /**
     * Undefined
     */
    public static final CallEventType CALL_EVENT_UNDEFINED = new CallEventType(_CALL_EVENT_UNDEFINED);

    /**
     * An originating call attempt takes place (for example Off-hook event).
     */
    public static final int _CALL_EVENT_ORIGINATING_CALL_ATTEMPT =  1;

    /**
     * An originating call attempt takes place (for example Off-hook event).
     */
    public static final CallEventType CALL_EVENT_ORIGINATING_CALL_ATTEMPT = new CallEventType(_CALL_EVENT_ORIGINATING_CALL_ATTEMPT);

    /**
     * An originating call attempt is authorised
     */
    public static final int _CALL_EVENT_ORIGINATING_CALL_ATTEMPT_AUTHORISED =  2;

    /**
     * An originating call attempt is authorised
     */
    public static final CallEventType CALL_EVENT_ORIGINATING_CALL_ATTEMPT_AUTHORISED = new CallEventType(_CALL_EVENT_ORIGINATING_CALL_ATTEMPT_AUTHORISED);

    /**
     * The destination address has been collected.
     */
    public static final int _CALL_EVENT_ADDRESS_COLLECTED =  3;

    /**
     * The destination address has been collected.
     */
    public static final CallEventType CALL_EVENT_ADDRESS_COLLECTED = new CallEventType(_CALL_EVENT_ADDRESS_COLLECTED);

    /**
     * The destination address has been analysed.
     */
    public static final int _CALL_EVENT_ADDRESS_ANALYSED =  4;

    /**
     * The destination address has been analysed.
     */
    public static final CallEventType CALL_EVENT_ADDRESS_ANALYSED = new CallEventType(_CALL_EVENT_ADDRESS_ANALYSED);

    /**
     * Mid-call originating service code received.
     */
    public static final int _CALL_EVENT_ORIGINATING_SERVICE_CODE =  5;

    /**
     * Mid-call originating service code received.
     */
    public static final CallEventType CALL_EVENT_ORIGINATING_SERVICE_CODE = new CallEventType(_CALL_EVENT_ORIGINATING_SERVICE_CODE);

    /**
     * A originating call/call leg is released
     */
    public static final int _CALL_EVENT_ORIGINATING_RELEASE =  6;

    /**
     * A originating call/call leg is released
     */
    public static final CallEventType CALL_EVENT_ORIGINATING_RELEASE = new CallEventType(_CALL_EVENT_ORIGINATING_RELEASE);

    /**
     * A terminating call attempt takes place
     */
    public static final int _CALL_EVENT_TERMINATING_CALL_ATTEMPT =  7;

    /**
     * A terminating call attempt takes place
     */
    public static final CallEventType CALL_EVENT_TERMINATING_CALL_ATTEMPT = new CallEventType(_CALL_EVENT_TERMINATING_CALL_ATTEMPT);

    /**
     * A terminating call is authorized
     */
    public static final int _CALL_EVENT_TERMINATING_CALL_ATTEMPT_AUTHORISED =  8;

    /**
     * A terminating call is authorized
     */
    public static final CallEventType CALL_EVENT_TERMINATING_CALL_ATTEMPT_AUTHORISED = new CallEventType(_CALL_EVENT_TERMINATING_CALL_ATTEMPT_AUTHORISED);

    /**
     * Call is alerting at the call party.
     */
    public static final int _CALL_EVENT_ALERTING =  9;

    /**
     * Call is alerting at the call party.
     */
    public static final CallEventType CALL_EVENT_ALERTING = new CallEventType(_CALL_EVENT_ALERTING);

    /**
     * Call answered at address.
     */
    public static final int _CALL_EVENT_ANSWER =  10;

    /**
     * Call answered at address.
     */
    public static final CallEventType CALL_EVENT_ANSWER = new CallEventType(_CALL_EVENT_ANSWER);

    /**
     * A terminating call leg has been released or the call could not be routed.
     */
    public static final int _CALL_EVENT_TERMINATING_RELEASE =  11;

    /**
     * A terminating call leg has been released or the call could not be routed.
     */
    public static final CallEventType CALL_EVENT_TERMINATING_RELEASE = new CallEventType(_CALL_EVENT_TERMINATING_RELEASE);

    /**
     * Call redirected to new address: an indication from the network that the call has been redirected to a new address (no events disarmed as a result of this).
     */
    public static final int _CALL_EVENT_REDIRECTED =  12;

    /**
     * Call redirected to new address: an indication from the network that the call has been redirected to a new address (no events disarmed as a result of this).
     */
    public static final CallEventType CALL_EVENT_REDIRECTED = new CallEventType(_CALL_EVENT_REDIRECTED);

    /**
     * Mid call terminating service code received.
     */
    public static final int _CALL_EVENT_TERMINATING_SERVICE_CODE =  13;

    /**
     * Mid call terminating service code received.
     */
    public static final CallEventType CALL_EVENT_TERMINATING_SERVICE_CODE = new CallEventType(_CALL_EVENT_TERMINATING_SERVICE_CODE);

    /**
     * The Call Event has been queued. (no events are disarmed as a result of this)
     */
    public static final int _CALL_EVENT_QUEUED =  14;

    /**
     * The Call Event has been queued. (no events are disarmed as a result of this)
     */
    public static final CallEventType CALL_EVENT_QUEUED = new CallEventType(_CALL_EVENT_QUEUED);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved CallEventType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the CallEventType object
     */
    public String getValueText() {
        switch (_value) {
            case _CALL_EVENT_UNDEFINED:
                return "CALL_EVENT_UNDEFINED";
            case _CALL_EVENT_ORIGINATING_CALL_ATTEMPT:
                return "CALL_EVENT_ORIGINATING_CALL_ATTEMPT";
            case _CALL_EVENT_ORIGINATING_CALL_ATTEMPT_AUTHORISED:
                return "CALL_EVENT_ORIGINATING_CALL_ATTEMPT_AUTHORISED";
            case _CALL_EVENT_ADDRESS_COLLECTED:
                return "CALL_EVENT_ADDRESS_COLLECTED";
            case _CALL_EVENT_ADDRESS_ANALYSED:
                return "CALL_EVENT_ADDRESS_ANALYSED";
            case _CALL_EVENT_ORIGINATING_SERVICE_CODE:
                return "CALL_EVENT_ORIGINATING_SERVICE_CODE";
            case _CALL_EVENT_ORIGINATING_RELEASE:
                return "CALL_EVENT_ORIGINATING_RELEASE";
            case _CALL_EVENT_TERMINATING_CALL_ATTEMPT:
                return "CALL_EVENT_TERMINATING_CALL_ATTEMPT";
            case _CALL_EVENT_TERMINATING_CALL_ATTEMPT_AUTHORISED:
                return "CALL_EVENT_TERMINATING_CALL_ATTEMPT_AUTHORISED";
            case _CALL_EVENT_ALERTING:
                return "CALL_EVENT_ALERTING";
            case _CALL_EVENT_ANSWER:
                return "CALL_EVENT_ANSWER";
            case _CALL_EVENT_TERMINATING_RELEASE:
                return "CALL_EVENT_TERMINATING_RELEASE";
            case _CALL_EVENT_REDIRECTED:
                return "CALL_EVENT_REDIRECTED";
            case _CALL_EVENT_TERMINATING_SERVICE_CODE:
                return "CALL_EVENT_TERMINATING_SERVICE_CODE";
            case _CALL_EVENT_QUEUED:
                return "CALL_EVENT_QUEUED";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 14
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static CallEventType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof CallEventType)) {
            return false;
        }
        CallEventType callEventType = (CallEventType) o; 
        if(!(this.getValue() == callEventType.getValue())) {
            return false;
        }
        if (this.hashCode() != callEventType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // CallEventType

