//Source file: CallLegAttachMechanism.java
//Date: December 2004
//Multi Party Call Control Data Types for 3GPP TS 29.198-04-3 V5.9.0

package org.csapi.jr.se.cc;

/**
 * Defines how a CallLeg should be attached to the call.
 *
 */
public final class CallLegAttachMechanism implements java.io.Serializable {

    private int _value;
    private static int _size = 2;
    private static CallLegAttachMechanism[] _array = new CallLegAttachMechanism[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private CallLegAttachMechanism(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * CallLeg should be attached implicitly to the call.
     */
    public static final int _CALLLEG_ATTACH_IMPLICITLY =  0;

    /**
     * CallLeg should be attached implicitly to the call.
     */
    public static final CallLegAttachMechanism CALLLEG_ATTACH_IMPLICITLY = new CallLegAttachMechanism(_CALLLEG_ATTACH_IMPLICITLY);

    /**
     * CallLeg should be attached explicitly to the call by using the attachMediaReq() operation. This allows for example the application to do first user interaction to the party before he/she is placed in the call.
     */
    public static final int _CALLLEG_ATTACH_EXPLICITLY =  1;

    /**
     * CallLeg should be attached explicitly to the call by using the attachMediaReq() operation. This allows for example the application to do first user interaction to the party before he/she is placed in the call.
     */
    public static final CallLegAttachMechanism CALLLEG_ATTACH_EXPLICITLY = new CallLegAttachMechanism(_CALLLEG_ATTACH_EXPLICITLY);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved CallLegAttachMechanism object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the CallLegAttachMechanism object
     */
    public String getValueText() {
        switch (_value) {
            case _CALLLEG_ATTACH_IMPLICITLY:
                return "CALLLEG_ATTACH_IMPLICITLY";
            case _CALLLEG_ATTACH_EXPLICITLY:
                return "CALLLEG_ATTACH_EXPLICITLY";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 1
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static CallLegAttachMechanism getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof CallLegAttachMechanism)) {
            return false;
        }
        CallLegAttachMechanism callLegAttachMechanism = (CallLegAttachMechanism) o; 
        if(!(this.getValue() == callLegAttachMechanism.getValue())) {
            return false;
        }
        if (this.hashCode() != callLegAttachMechanism.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // CallLegAttachMechanism

